//
//  SCAdViewController.h
//  SCMobileSDK
//
//  Copyright © 2018 smartclip Holding AG. All rights reserved.
//

#import <UIKit/UIKit.h>
#import <WebKit/WebKit.h>
#import "SCAdListener.h"
#import "SCAdConfiguration.h"

@class SCAdContentView;

/// Type definition for SCAdInfo completion handler
typedef void (^SCAdInfoCompletionHandler)(id _Nullable info, NSError  * _Nullable error);

/**
 SCAdViewController is the ViewController that is responsible for playing smartclip advertisement videos. The ViewController utilizes a WKWebView which uses smartclip javascript core code to execute the advertisements.

 You can set SCDisablePlayerScriptUpdate to YES in your projects plist file if you want to use the javascript player that is part of this bundle. Otherwise the player will be updated automatically.
 */
@interface SCAdViewController : UIViewController
/// The target sdk listener. Set this to get informed by state changes from this controller.
@property (nonatomic, weak) id<SCAdListener> listener;

/// The view your ads are displayed in
@property (nonatomic, readonly, weak) SCAdContentView *contentView;

- (id)initWithConfiguration:(SCAdConfiguration*)configuration;

/**
 Recommended method for initializing SCAdController. Submit a view (contentView) of your layout
 To define the location where the ad is to be played. Also, you need to pass your adURL
 Specifies the type of ads and other attributes such as execution order or count.
 
 - Parameter contentView: the view container the ad video will be displayed in
 - Parameter adUrl: the url the ad SDK will use to show the video ads.
 */
- (id)initWithContentView:(SCAdContentView*)contentView configuration:(SCAdConfiguration*)configuration;

/// play / continue with currently set smartclip advertising video
- (void)play;

/// pause with currently set smartclip advertising video
- (void)pause;

/// check if the currently set smartclip advertising video is paused
- (BOOL)isPaused;

/// check if the currently set smartclip advertising video has ended
- (BOOL)hasEnded;

/// check if the currently set smartclip advertising video is available
- (BOOL)isAvailable;

/*
 The URL you got from us. Required by SDK to choose customized advertising clips. Please contact us if you have not yet received your ad URL or do not know what that means.
*/
- (NSString*)adURL;

/// Has to be called when ScAdConfiguration.useExtendedClickThru is used and the click thru url was shown to the user.
- (void)clickThruAccepted;

/// Has to be called when ScAdConfiguration.useExtendedClickThru is used and the click thru url was NOT shown to the user.
- (void)clickThruRejected;

/// Overwrites the UIViewControllers removeFromParentViewController method. This will additionally remove the ad view from view hierarchy.
- (void)removeFromParentViewController;

/// Can be used to get the current adInfo object from the webView
- (void)getAdInfoWith:(SCAdInfoCompletionHandler)completionHandler;
@end
